==> zio-aws-lightsail_2.12-5.17.172.1-sources.jar: zio/aws/lightsail/model/GetDistributionLatestCacheResetRequest.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.ResourceName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetDistributionLatestCacheResetRequest(
    distributionName: Optional[ResourceName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest = {
    import GetDistributionLatestCacheResetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
      .builder()
      .optionallyWith(
        distributionName.map(value =>
          ResourceName.unwrap(value): java.lang.String
        )
      )(_.distributionName)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest.ReadOnly =
    zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest
      .wrap(buildAwsValue())
}
object GetDistributionLatestCacheResetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest =
      zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest(
        distributionName.map(value => value)
      )
    def distributionName: Optional[ResourceName]
    def getDistributionName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("distributionName", distributionName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
  ) extends zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest.ReadOnly {
    override val distributionName: Optional[ResourceName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.distributionName())
        .map(value => zio.aws.lightsail.model.primitives.ResourceName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
  ): zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/GetDistributionLatestCacheResetRequest.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.ResourceName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetDistributionLatestCacheResetRequest(
    distributionName: Option[ResourceName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest = {
    import GetDistributionLatestCacheResetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
      .builder()
      .optionallyWith(
        distributionName.map(value =>
          ResourceName.unwrap(value): java.lang.String
        )
      )(_.distributionName)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest.ReadOnly =
    zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest
      .wrap(buildAwsValue())
}
object GetDistributionLatestCacheResetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest =
      zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest(
        distributionName.map(value => value)
      )
    def distributionName: Option[ResourceName]
    def getDistributionName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("distributionName", distributionName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
  ) extends zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest.ReadOnly {
    override val distributionName: Option[ResourceName] = scala
      .Option(impl.distributionName())
      .map(value => zio.aws.lightsail.model.primitives.ResourceName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetDistributionLatestCacheResetRequest
  ): zio.aws.lightsail.model.GetDistributionLatestCacheResetRequest.ReadOnly =
    new Wrapper(impl)
}
